/// <reference types="node" />
import { EventEmitter } from 'events';
import { Socket } from 'socket.io';
declare type UploaderOptions = {
    /**
     * max file: 200MB
     */
    maxFileSize: number;
    /**
     * socket event name prefix
     */
    prefix: string;
};
declare type FileInfo = {
    name: any;
    mtime: Date;
    encoding: any;
    clientDetail: any;
    meta: any;
    id: any;
    size: any;
    bytesLoaded: number;
    success: boolean;
    /**
     * buffer
     */
    buffer: Buffer;
};
/**
 * interface for events
 */
export interface Uploader {
    on(event: 'start', listener: (params: {
        file: FileInfo;
    }) => void): this;
    on(event: 'progress', listener: (params: {
        file: FileInfo;
        buffer: Buffer;
    }) => void): this;
    on(event: 'complete', listener: (params: {
        file: FileInfo;
        interrupt: boolean;
    }) => void): this;
    on(event: 'error', listener: (params: {
        file: FileInfo;
        error: Error;
        message: 'disconnect during upload';
    }) => void): this;
    /**
     * @param file
     */
    detailProvider(params: {
        file: FileInfo;
        interrupt: boolean;
    }): Promise<any>;
    /**
     * @param file
     */
    validate(file: FileInfo): Promise<boolean>;
}
/**
 * socket.io
 */
export declare class Uploader extends EventEmitter {
    private readonly options;
    constructor(options?: Partial<UploaderOptions>);
    private get maxFileSize();
    /**
     * files
     */
    private files;
    /**
     * get event with prefix
     * @param event
     */
    private getSocketEventName;
    /**
     * Public method.  Abort an upload that may be in progress.  Throws an
     * exception if the specified file upload is not in progress.
     *
     * @param  {String} id     The ID of the file upload to abort.
     * @param  {Socket} socket The socket that this instance is connected to.
     * @return {void}
     */
    private abort;
    /**
     * clean file
     * @param id
     */
    private cleanupFile;
    /**
     * listen on socket
     * @param socket
     */
    listenSocket(socket: Socket): this;
    /**
     * start
     * @param data
     * @param socket
     */
    private handleStart;
    /**
     * 处理上传进度条
     * @param data
     * @param socket
     */
    private handleProgress;
    /**
     * done
     * @param data
     * @param socket
     */
    private handleDone;
}
export {};
